# umlviz

A tool for generating UML blocks using a dev-friendly domain-specfic language

# Usage

Example class file:
```
class BaseClass {
  int m_member1
  int m_member2
  print()
}
```

Generating a PNG from the command line:
```
umlviz output-name png input.uvz # This takes o
``` 
